# Patching guideline for python :
# - no big patch with invasive change not 
#     approved by upstream ( ie not coming from upstream svn )
# - small bugfix must be sent to upstream and approved if they 
#     change any interface
# - all patchs should be commented ( unless for security, 
#     as they are usually easy to spot )
%define subrel 2

%define docver  2.7.6
%define dirver  2.7

%define lib_major       %{dirver}
%define lib_name_orig   libpython
%define lib_name        %mklibname %{name} %{lib_major}
%define dev_name        %mklibname %{name} -d

%define arch_has_valgrind 1
%ifarch %arm %mips
%define arch_has_valgrind 0
%endif

%if %arch_has_valgrind
%bcond_without  valgrind
%else
%bcond_with     valgrind
%endif

# Some of the files below /usr/lib/pythonMAJOR.MINOR/test  (e.g. bad_coding.py)
# are deliberately invalid, leading to SyntaxError exceptions if they get
# byte-compiled.
#
# These errors are ignored by the normal python build, and aren't normally a
# problem in the buildroots since /usr/bin/python isn't present.
# 
# So we disable here brp-python-bytecompile
#
%define _python_bytecompile_build 0


Summary:        An interpreted, interactive object-oriented programming language
Name:           python
Version:        2.7.6
Release:        %mkrel 1
License:        Modified CNRI Open Source License
Group:          Development/Python
Url:            http://www.python.org/

Source0:        http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.xz
Source1:        http://www.python.org/ftp/python/doc/%{docver}/python-%{docver}-docs-html.tar.bz2
Source4:        python-mode-1.0.tar.bz2
Patch0:         python-2.7.5-module-linkage.patch
# Don't include /usr/local/* in search path
Patch3:         Python-2.7.6-no-local-incpath.patch

# Support */lib64 convention on x86_64, sparc64, etc.
# similar patches reported upstream on http://bugs.python.org/issue1294959
Patch4:         python-lib64.patch

# Do handle <asm-XXX/*.h> headers in h2py.py
# FIXME: incomplete for proper bi-arch support as #if/#else/#endif
# clauses generally should have been handled
# to send upstream after cleaning
Patch5:         Python-2.2.2-biarch-headers.patch

# add mandriva to the list of supported distribution, applied upstream
Patch10:        python-2.5.1-detect-mandriva.patch

# from Fedora, fixes gettext.py parsing of Plural-Forms: header (fixes mdv bugs #49475, #44088)
# to send upstream
Patch16:        python-2.5.1-plural-fix.patch

# ffi checks for MIPS_LINUX instead of MIPS
Patch23:        python-2.7-mips-ffi.patch

# do not use uname -m to get the exact name on mips/arm
Patch24:        python_arch.patch

# fix https://bugs.mageia.org/show_bug.cgi?id=481
# mdv bug #62281 
# patch to cope with lack of /dev/shm in iurt 
Patch25:        python-2.7.5-skip-shm-test.patch 
# CVE-2013-1753 [bnc#856835] unbounded gzip decompression in xmlrpc client
Patch26:        xmlrpc_gzip_27.patch
# CVE-2013-1752 patches missing in 2.7.6: imaplib, poplib, smtplib
Patch27:        python-2.7.6-imaplib.patch
Patch28:        smtplib_maxline-2.7.patch
Patch29:        python-2.7.6-poplib.patch

Patch130:       Python-2.7.5-check-for-XML_SetHashSalt.diff

# 00173 #
# Workaround for ENOPROTOOPT seen in bs within
# test.test_support.bind_port()
# from Fedora (rhbz#913732)
Patch173:       00173-workaround-ENOPROTOOPT-in-bind_port.patch
# Fixing buffer overflow (upstream patch)
Patch192:       python-2.7.6-buffer-overflow-CVE-2014-1912.patch
# http://bugs.python.org/issue21766
Patch193:       python-2.7.6-CVE-2014-4650.patch
# http://bugs.python.org/issue21529
Patch194:       python-2.7.6-CVE-2014-4616.patch

Conflicts:      tkinter < %{version}
Conflicts:      python-devel < 2.7-6
Requires:       %{lib_name} = %{version}
BuildRequires:  blt
BuildRequires:  db5-devel
BuildRequires:  emacs-bin
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  ncursesw-devel
BuildRequires:  openssl-devel
BuildRequires:  readline-devel
BuildRequires:  termcap-devel
BuildRequires:  tk-devel
BuildRequires:  tix
BuildRequires:  autoconf2.5
BuildRequires:  bzip2-devel
BuildRequires:  sqlite3-devel
BuildRequires:  emacs
%if %{with valgrind}
BuildRequires:  valgrind-devel
%endif

# (2010/03/21, misc: interfere with test__all )
BuildConflicts: python-pyxml

Provides:       python(abi) = %dirver
%rename python-ctypes
%rename python-elementtree
Obsoletes:      python-base < 2.6
Provides:       python-base = %version

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package -n     %{lib_name}
Summary:        Shared libraries for Python %{version}
Group:          System/Libraries

%description -n %{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n     %{dev_name}
Summary:        The libraries and header files needed for Python development
Group:          Development/Python
Requires:       %{name} = %version
Requires:       %{lib_name} = %{version}
Obsoletes:      %{name}-devel < %{version}
# (misc) needed to ease upgrade , see #47803
Obsoletes:      %mklibname -d %{name} 2.5
Obsoletes:      %mklibname -d %{name} 2.6
Obsoletes:      %{mklibname -d %{name} 2.7} < 2.7-4
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}

%description -n %{dev_name}
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{dev_name} if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package        docs
Summary:        Documentation for the Python programming language
Requires:       python = %version
Requires:       xdg-utils
Group:          Development/Python
BuildArch:      noarch

%description    docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n     tkinter
Summary:        A graphical user interface for the Python scripting language
Group:          Development/Python
Requires:       python = %version
Requires:       tcl tk

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%package -n     tkinter-apps
Summary:        Various applications written using tkinter
Group:          Development/Python
Requires:       tkinter

%description -n tkinter-apps
Various applications written using tkinter

%prep
%setup -q -n Python-%{version}
%patch0 -p0
# local include
%patch3 -p0
# lib64
%patch4 -p0 -b .lib64

# biarch header
%patch5 -p0

# add mandriva to the list of supported distribution
%patch10 -p0


%patch16 -p1 -b .plural-fix

%patch23 -p1 -b .mips
%patch24 -p1 -b .arch
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1

%patch130 -p1 -b .check-for-XML_SetHashSalt
%patch173 -p1
%patch192 -p1
%patch193 -p1
%patch194 -p1

autoconf

mkdir html
bzcat %{SOURCE1} | tar x  -C html
find html -type d |xargs chmod 755
find html -type f |xargs chmod 644

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python@'

tar --strip-components=1 -xjf %{SOURCE4} -C Misc

cat > README.mga << EOF
Python interpreter support readline completion by default.
This is only used with the interpreter. In order to remove it,
you can :
1) unset PYTHONSTARTUP when you login
2) create a empty file \$HOME/.pythonrc.py
3) change %{_sysconfdir}/pythonrc.py
EOF
# make sur the IN.py TYPES.py and DLFCN.py are correct
# for current arch otherwise things will start failing
# in weird ways
pushd Lib/plat-linux2/
../../Tools/scripts/h2py.py -i '(u_long)' /usr/include/sys/types.h /usr/include/netinet/in.h /usr/include/dlfcn.h
popd

%build
rm -f Modules/Setup.local
cat > Modules/Setup.local << EOF
linuxaudiodev linuxaudiodev.c
EOF

OPT="$RPM_OPT_FLAGS -g"
export OPT

# to fix curses module build
# https://bugs.mageia.org/show_bug.cgi?id=5524
export CFLAGS="%{optflags} -I/usr/include/ncursesw"
export CPPFLAGS="%{optflags} -I/usr/include/ncursesw"
# Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102:
# https://bugs.mageia.org/show_bug.cgi?id=9395
# https://bugs.mageia.org/show_bug.cgi?id=10102
%define _disable_ld_no_undefined 1

# see https://qa.mandriva.com/show_bug.cgi?id=48570 
# for wide unicode support
%configure2_5x  --with-threads \
        --enable-unicode=ucs4 \
        --with-dbmliborder=gdbm \
        --enable-ipv6 \
        --enable-shared \
        --with-system-expat \
        --with-system-ffi \
%if %{with valgrind}
        --with-valgrind
%endif

# fix build
#perl -pi -e 's/^(LDFLAGS=.*)/$1 -lstdc++/' Makefile
# (misc) if the home is nfs mounted, rmdir fails due to delay
export TMP="/tmp" TMPDIR="/tmp"
make

%check
# (misc) if the home is nfs mounted, rmdir fails
export TMP="/tmp" TMPDIR="/tmp"

# all tests must pass
%ifarch %arm
# don't know if it's a python issue or a toolchain issue :(
# test test_float failed -- Traceback (most recent call last):
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 665, in test_from_hex
#    self.identical(fromHex('0x0.ffffffffffffd6p-1022'), MIN-3*TINY)
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 375, in identical
#    self.fail('%r not identical to %r' % (x, y))
# AssertionError: 2.2250738585071999e-308 not identical to 2.2250738585071984e-308
%define custom_test -x test_float
%else
%define custom_test ""
%endif 
# if a test doesn't pass, it can be disabled with -x test, but this should be documented in the
# spec file, and a bug should be reported if possible ( on python side )
# (misc, 28/10/2010) test_gdb fail, didn't time too look
# (misc, 29/10/2010) test_site fail due to one of our patch, will fix later
#   test_distutils, fail because of lib64 patch ( like test_site ), and because it requires libpython2.7 to be installed
#   test_io, blocks on my computer on 2nd run
# (misc, 22/05/2011) test_urllib2 fail, related to CVE-2011-1521 :
# test test_urllib2 failed -- Traceback (most recent call last):
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/test/test_urllib2.py", line 990, in test_invalid_redirect
#    MockHeaders({"location": valid_url}))
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/urllib2.py", line 617, in http_error_302
#    return self.parent.open(new, timeout=req.timeout)
#  File "/home/iurt/rpm/BUILD/Python-2.7.1/Lib/urllib2.py", line 219, in __getattr__
#    raise AttributeError, attr
# AttributeError: timeout

WITHIN_PYTHON_RPM_BUILD= make test TESTOPTS="-w -l -x test_gdb -x test_site -x test_io -x test_distutils -x test_urllib2 %custom_test"

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p %buildroot%{_prefix}/lib/python%{dirver}

# fix Makefile to get rid of reference to distcc
perl -pi -e "/^CC=/ and s/distcc/gcc/" Makefile

# set the install path
echo '[install_scripts]' >setup.cfg
echo 'install_dir='"${RPM_BUILD_ROOT}/usr/bin" >>setup.cfg

# python is not GNU and does not know fsstd
mkdir -p $RPM_BUILD_ROOT%{_mandir}
%makeinstall_std

(cd $RPM_BUILD_ROOT%{_libdir}; ln -sf libpython%{lib_major}.so.* libpython%{lib_major}.so)

# Provide a libpython%{dirver}.so symlink in /usr/lib/puthon*/config, so that
# the shared library could be found when -L/usr/lib/python*/config is specified
(cd $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/config; ln -sf ../../libpython%{lib_major}.so .)

# emacs, I use it, I want it
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
install -m 644 Misc/python-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
emacs -batch -f batch-byte-compile $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/python-mode.el

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.py$" . python-mode) auto-mode-alist))
(autoload 'python-mode "python-mode" "Mode for python files." t)
EOF

#"  this comment is just here because vim syntax higlighting is confused by the previous snippet of lisp

# smtpd proxy
mv -f $RPM_BUILD_ROOT%{_bindir}/smtpd.py $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/

# idle
cp Tools/scripts/idle $RPM_BUILD_ROOT%{_bindir}/idle


# pynche
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/pynche
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/site-packages/

chmod 755 $RPM_BUILD_ROOT%{_bindir}/{idle,pynche}

ln -f Tools/pynche/README Tools/pynche/README.pynche

%if %{with valgrind}
install Misc/valgrind-python.supp -D $RPM_BUILD_ROOT%{_libdir}/valgrind/valgrind-python.supp
%endif

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{_real_vendor}-tkinter.desktop << EOF
[Desktop Entry]
Name=IDLE
Comment=IDE for Python
Exec=%{_bindir}/idle
Icon=development_environment_section
Terminal=false
Type=Application
Categories=Development;IDE;
EOF


cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop << EOF
[Desktop Entry]
Name=Python documentation
Comment=Python complete reference
Exec=%{_bindir}/xdg-open %_defaultdocdir/%{name}-docs/index.html
Icon=documentation_section
Terminal=false
Type=Application
Categories=Documentation;
EOF


# fix non real scripts
chmod 644 $RPM_BUILD_ROOT%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
# fix python library not stripped
chmod u+w $RPM_BUILD_ROOT%{_libdir}/libpython%{lib_major}.so.1.0


mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/

cat > $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/30python2.sh << 'EOF'
if [ -f $HOME/.pythonrc.py ] ; then
        export PYTHONSTARTUP=$HOME/.pythonrc.py
else
        export PYTHONSTARTUP=/etc/pythonrc.py
fi
EOF

cat > $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d/30python2.csh << 'EOF'
if ( -f ${HOME}/.pythonrc.py ) then
        setenv PYTHONSTARTUP ${HOME}/.pythonrc.py
else
        setenv PYTHONSTARTUP /etc/pythonrc.py
endif
EOF

cat > $RPM_BUILD_ROOT%{_sysconfdir}/pythonrc.py << EOF
try:
    # this add completion to python interpreter
    import readline
    import rlcompleter
    # see readline man page for this
    readline.parse_and_bind("set show-all-if-ambiguous on")
    readline.parse_and_bind("tab: complete")
except:
    pass
# you can place a file .pythonrc.py in your home to overrides this one
# but then, this file will not be sourced
EOF

%multiarch_includes $RPM_BUILD_ROOT/usr/include/python*/pyconfig.h

%files
%doc README.mga
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%config(noreplace) %{_sysconfdir}/profile.d/30python2.*
%config(noreplace) %{_sysconfdir}/pythonrc.py
# "Makefile" and the config.h file are needed by
# distutils/sysconfig.py:_init_posix(), so we include them in the libs
# package, along with their parent directories (RH bug#531901):
%dir %{_libdir}/python%{dirver}/config
%{_libdir}/python%{dirver}/config/Makefile
%dir %{_includedir}/python%{dirver}
%{_includedir}/python%{dirver}/pyconfig.h
%multiarch %multiarch_includedir/python%{dirver}/pyconfig.h

%exclude %{_libdir}/python%{dirver}/config/Setup
%exclude %{_libdir}/python%{dirver}/config/Setup.config
%exclude %{_libdir}/python%{dirver}/config/Setup.local
%exclude %{_libdir}/python%{dirver}/config/config.c
%exclude %{_libdir}/python%{dirver}/config/config.c.in
%exclude %{_libdir}/python%{dirver}/config/install-sh
%exclude %{_libdir}/python%{dirver}/config/libpython2.7.a
%exclude %{_libdir}/python%{dirver}/config/libpython2.7.so
%exclude %{_libdir}/python%{dirver}/config/makesetup
%exclude %{_libdir}/python%{dirver}/config/python.o
%exclude %{_libdir}/python%{dirver}/test/
%exclude %{_libdir}/python%{dirver}/idlelib
%exclude %{_libdir}/python%{dirver}/lib-tk
%exclude %{_libdir}/python%{dirver}/lib-dynload/_tkinter.so
%exclude %{_libdir}/python%{dirver}/site-packages/pynche

%{_libdir}/python%{dirver}
%if "%{_lib}" != "lib"
%{_prefix}/lib/python%{dirver}
%endif
%{_bindir}/python2
%{_bindir}/python%{dirver}
%{_bindir}/pydoc
%{_bindir}/python
%{_bindir}/2to3
%{_datadir}/emacs/site-lisp/*
%{_mandir}/man*/*
%if %{with valgrind}
%{_libdir}/valgrind/valgrind-python.supp
%endif

%files -n %{lib_name}
%{_libdir}/libpython*.so.1*

%files -n %{dev_name}
%{_libdir}/libpython*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/python%{dirver}
%{_libdir}/python%{dirver}/config/*
%{_libdir}/python%{dirver}/test/
%{_bindir}/python%{dirver}-config
%{_bindir}/python-config
%{_bindir}/python2-config
%exclude %{_libdir}/python%{dirver}/config/Makefile
%exclude %{_includedir}/python%{dirver}/pyconfig.h

%files docs
%doc html/*/*
%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop

%files -n tkinter
%dir %{_libdir}/python%{dirver}/lib-tk
%{_libdir}/python%{dirver}/lib-tk/*.py*
%{_libdir}/python%{dirver}/lib-tk/test/
%{_libdir}/python%{dirver}/lib-dynload/_tkinter.so
%{_libdir}/python%{dirver}/idlelib
%{_libdir}/python%{dirver}/site-packages/pynche

%files -n tkinter-apps
%{_bindir}/idle
%{_bindir}/pynche
%{_datadir}/applications/%{_real_vendor}-tkinter.desktop




%changelog
* Sat Jun 28 2014 philippem <philippem> 2.7.6-1.2.mga4
+ Revision: 640875
- fix CVE-2014-4650 and CVE-2014-4616 mga#15588)
- added patches for CVE-2013-1752 (mga#12127) issues that are
  missing in 2.7.6:
  python-2.7.6-imaplib.patch
  python-2.7.6-poplib.patch
  smtplib_maxline-2.7.patch
- CVE-2013-1753 (mga#13041) gzip decompression bomb in xmlrpc client:
  xmlrpc_gzip_27.patch
- update to 2.7.6 with also fix buffer overflow CVE-2014-1912

* Tue Oct 22 2013 umeabot <umeabot> 2.7.5-11.mga4
+ Revision: 545491
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7.5-10.mga4
+ Revision: 498057
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Sep 26 2013 fwang <fwang> 2.7.5-9.mga4
+ Revision: 486490
- drop conflicts could not be satisfied

* Wed Sep 25 2013 philippem <philippem> 2.7.5-8.mga4
+ Revision: 486298
+ rebuild (emptylog)

* Wed Sep 25 2013 fwang <fwang> 2.7.5-7.mga4
+ Revision: 485888
- versioned obsoletes

* Wed Sep 25 2013 fwang <fwang> 2.7.5-6.mga4
+ Revision: 485866
- add conflicts to ease upgrade

* Tue Sep 24 2013 philippem <philippem> 2.7.5-5.mga4
+ Revision: 485674
- remove PYTHONDONTWRITEBYTECODE=1 fix mga#3348
- profile.d files as configfile noreplace fix mga#10758

* Mon Aug 12 2013 oden <oden> 2.7.5-4.mga4
+ Revision: 465654
- P174: security fix for CVE-2013-4073 (upstream)

* Wed Jun 26 2013 philippem <philippem> 2.7.5-3.mga4
+ Revision: 447236
- Convert inconsistent indentation to spaces only to be in synch with python3 package

* Tue Jun 25 2013 philippem <philippem> 2.7.5-2.mga4
+ Revision: 446643
- Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102
- Remove -Wl,--no-undefined in Makefile in accordance with MGA #9395 and MGA #10102

* Tue May 28 2013 tv <tv> 2.7.5-1.mga4
+ Revision: 429662
- new release
- rediff patches

* Tue May 28 2013 tv <tv> 2.7.3-8.mga4
+ Revision: 429649
- make docs readable by !root...

* Sun Jan 13 2013 umeabot <umeabot> 2.7.3-7.mga3
+ Revision: 378425
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 06 2012 luigiwalser <luigiwalser> 2.7.3-6.mga3
+ Revision: 278990
- rebuild for libffi

* Mon Jul 30 2012 tv <tv> 2.7.3-5.mga3
+ Revision: 276242
- rebuild for db-5.3

* Tue Jul 10 2012 luigiwalser <luigiwalser> 2.7.3-4.mga3
+ Revision: 269231
- add patch from rhel6 via mdv to verify that XML_SetHashSalt is in expat

* Mon Jun 18 2012 obgr_seneca <obgr_seneca> 2.7.3-3.mga3
+ Revision: 261795
- use system expat and ffi instead of bundled ones
- clean BRs
- Added patch for CVE-2011-4944 (Mga Bug #5843)

* Thu Jun 14 2012 tv <tv> 2.7.3-2.mga3
+ Revision: 260509
- build with db5.2

* Sun Apr 22 2012 wally <wally> 2.7.3-2.mga2
+ Revision: 232502
- fix _curses module build (mga#5524)

* Thu Apr 19 2012 fwang <fwang> 2.7.3-1.mga2
+ Revision: 231756
- update file list
- use xz tarball
- update file list
- new version 2.7.3

  + guillomovitch <guillomovitch>
    - spec cleanup
    - rename distribution-specific documentation file to README.mga

* Mon Dec 05 2011 fwang <fwang> 2.7.2-3.mga2
+ Revision: 176928
- add upstream patch to recognize gdbm 1.9 magic value
- build with gdbm
- rebuild for new gdbm

* Fri Sep 02 2011 tv <tv> 2.7.2-2.mga2
+ Revision: 137806
- make the huge doc subpackage be noarch

* Sat Jul 02 2011 fwang <fwang> 2.7.2-1.mga2
+ Revision: 117293
- br valgrind-devel
- new version 2.7.2

* Mon May 23 2011 misc <misc> 2.7.1-6.mga1
+ Revision: 100214
- do not duplicate line wth test ( especially since this mean some of them will be out of sync
- disable test_urllib2, as the test added by latest CVE do not seems to work ( at least on
  our builder bot ) and we are soon releasing

  + dmorgan <dmorgan>
    - P26: security fix for CVE-2011-1521

* Thu May 05 2011 misc <misc> 2.7.1-5.mga1
+ Revision: 95183
- reuse mandriva patch made by Guillomovitch to fix mga#481

* Thu May 05 2011 misc <misc> 2.7.1-4.mga1
+ Revision: 95087
- update patch to make sure that semaphore are enabled ( 2nd attempt at bug 481 )

* Tue Apr 26 2011 wally <wally> 2.7.1-3.mga1
+ Revision: 91819
- fix desktop file names (mga#954)
- drop buildroot definition

* Thu Apr 14 2011 misc <misc> 2.7.1-2.mga1
+ Revision: 85334
- add fix for mageia bug 481, patch by Panos Christeas, to force
  detection of sem_open

  + rtp <rtp>
    - fix ffi check on mips
    - regenerate IN.py/DLFCN.py/... at build time to make sure they're fine on current arch
    - fix arch detection
    - disable float test on arm

* Sun Jan 16 2011 misc <misc> 2.7.1-1.mga1
+ Revision: 20497
- built without db2 support ( was dropped from fedora, and i do not really know
  why we keep it )
- remove old compatibility macros

  + blino <blino>
    - imported package python

